@@ -64,6 +64,11 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def setUp(self):
         self.configure()
 
+        if self.r.config.is_reddit:
+            self.self_url = self.url('/r/programming/comments/bn2wi/')
+        else:
+            self.self_url = self.url('/r/bboe/comments/2z/tasdest/')
+
     def test_comments_contains_no_noncomment_objects(self):
         if self.r.config.is_reddit:
             url = self.url('/r/programming/comments/bn2wi/')
@@ -78,10 +83,18 @@ class BasicTest(unittest.TestCase, BasicHelper):
         num = 50
         self.assertEqual(num, len(list(self.r.get_all_comments(limit=num))))
 
+    def test_get_controversial(self):
+        num = 50
+        self.assertEqual(num, len(list(self.r.get_controversial(limit=num))))
+
     def test_get_front_page(self):
         num = 50
         self.assertEqual(num, len(list(self.r.get_front_page(limit=num))))
 
+    def test_get_new(self):
+        num = 50
+        self.assertEqual(num, len(list(self.r.get_new(limit=num))))
+
     def test_flair_list(self):
         sub = self.r.get_subreddit('python')
         self.assertTrue(six_next(sub.flair_list()))
@@ -100,7 +113,7 @@ class BasicTest(unittest.TestCase, BasicHelper):
     def test_info_by_self_url_raises_warning(self):
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter('always')
-            self.r.info(self.self)
+            self.r.info(self.self_url)
             self.assertEqual(len(w), 1)
             self.assertEqual(w[-1].category, UserWarning)
             self.assertTrue('self' in text_type(w[-1].message))
